package com.jiuqi.util;

import java.io.File;
import java.util.jar.Attributes;
import java.util.jar.Manifest;

public class BundleUtils {
   public static String getBundleId(String path) {
      return getBundleId(new File(path));
   }

   public static String getBundleId(File path) {
      Manifest manifest = ManifestUtil.getManifest(path);
      if (manifest == null) {
         return null;
      } else {
         Attributes attrs = manifest.getMainAttributes();
         String bundleId = ManifestUtil.getAttributeValue(attrs, "Bundle-SymbolicName");
         return bundleId;
      }
   }

   public static boolean isBundle(String path) {
      return isBundle(new File(path));
   }

   public static boolean isBundle(File path) {
      String id = getBundleId(path);
      return id != null && !"".equals(id);
   }

   public static boolean isHostBundle(String path) {
      return isHostBundle(new File(path));
   }

   public static boolean isHostBundle(File path) {
      Manifest manifest = ManifestUtil.getManifest(path);
      if (manifest == null) {
         return false;
      } else {
         Attributes attrs = manifest.getMainAttributes();
         String bundleId = ManifestUtil.getAttributeValue(attrs, "Bundle-SymbolicName");
         if (bundleId == null) {
            return false;
         } else {
            String bundleLocalization = ManifestUtil.getAttributeValue(attrs, "Bundle-Localization");
            return bundleLocalization == null || "plugin".equalsIgnoreCase(bundleLocalization);
         }
      }
   }

   public static boolean isFragmentBundle(String path) {
      return isFragmentBundle(new File(path));
   }

   public static boolean isFragmentBundle(File path) {
      Manifest manifest = ManifestUtil.getManifest(path);
      if (manifest == null) {
         return false;
      } else {
         Attributes attrs = manifest.getMainAttributes();
         String bundleId = ManifestUtil.getAttributeValue(attrs, "Bundle-SymbolicName");
         if (bundleId == null) {
            return false;
         } else {
            String fragmentHost = ManifestUtil.getAttributeValue(attrs, "Fragment-Host");
            if (fragmentHost != null) {
               return true;
            } else {
               String bundleLocalization = ManifestUtil.getAttributeValue(attrs, "Bundle-Localization");
               return "fragment".equalsIgnoreCase(bundleLocalization);
            }
         }
      }
   }
}
